@@ -11,6 +11,7 @@ import (
 	"os"
 	"os/exec"
 	"os/user"
+	"path/filepath"
 	"reflect"
 	"regexp"
 	"runtime"
@@ -119,6 +120,7 @@ type Config struct {
 	managed         managedCmdConfig
 	purge           purgeCmdConfig
 	reAdd           reAddCmdConfig
+	remove          removeCmdConfig
 	secretKeyring   secretKeyringCmdConfig
 	state           stateCmdConfig
 	status          statusCmdConfig
@@ -520,7 +522,7 @@ func (c *Config) applyArgs(targetSystem chezmoi.System, targetDirAbsPath chezmoi
 		}
 	}
 	if keptGoingAfterErr {
-		return ErrExitCode(1)
+		return ExitCodeError(1)
 	}
 
 	return nil
@@ -610,7 +612,7 @@ func (c *Config) defaultPreApplyFunc(targetRelPath chezmoi.RelPath, targetEntryS
 		case choice == "skip":
 			return chezmoi.Skip
 		case choice == "quit":
-			return ErrExitCode(1)
+			return ExitCodeError(1)
 		default:
 			return nil
 		}
@@ -750,6 +752,7 @@ type destAbsPathInfosOptions struct {
 func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []string, options destAbsPathInfosOptions) (map[chezmoi.AbsPath]fs.FileInfo, error) {
 	destAbsPathInfos := make(map[chezmoi.AbsPath]fs.FileInfo)
 	for _, arg := range args {
+		arg = filepath.Clean(arg)
 		destAbsPath, err := chezmoi.NewAbsPathFromExtPath(arg, c.homeDirAbsPath)
 		if err != nil {
 			return nil, err
