@@ -67,6 +67,9 @@ type dirCheck struct {
 	dirname string
 }
 
+// An executableCheck checks the executable.
+type executableCheck struct{}
+
 // A fileCheck checks that a file exists.
 type fileCheck struct {
 	name       string
@@ -116,6 +119,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionStr:  c.versionStr,
 		},
 		&osArchCheck{},
+		&executableCheck{},
 		&fileCheck{
 			name:       "config-file",
 			filename:   string(c.configFileAbsPath),
@@ -255,7 +259,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 	resultWriter.Flush()
 
 	if worstResult > checkWarning {
-		return ErrExitCode(1)
+		return ExitCodeError(1)
 	}
 
 	return nil
@@ -319,6 +323,18 @@ func (c *dirCheck) Run() (checkResult, string) {
 	return checkOK, fmt.Sprintf("%s is a directory", c.dirname)
 }
 
+func (c *executableCheck) Name() string {
+	return "executable"
+}
+
+func (c *executableCheck) Run() (checkResult, string) {
+	executable, err := os.Executable()
+	if err != nil {
+		return checkError, err.Error()
+	}
+	return checkOK, executable
+}
+
 func (c *fileCheck) Name() string {
 	return c.name
 }
@@ -367,17 +383,20 @@ func (c *suspiciousEntriesCheck) Run() (checkResult, string) {
 			return err
 		}
 		if chezmoi.SuspiciousSourceDirEntry(filepath.Base(path), info) {
-			suspiciousEntries = append(suspiciousEntries, path)
+			relPath, err := filepath.Rel(c.dirname, path)
+			if err != nil {
+				return err
+			}
+			suspiciousEntries = append(suspiciousEntries, relPath)
 		}
 		return nil
 	}); err != nil {
 		return checkError, err.Error()
 	}
 	if len(suspiciousEntries) > 0 {
-		return checkWarning, fmt.Sprintf("found suspicious entries in %s: %s", c.dirname, strings.Join(suspiciousEntries, ", "))
+		return checkWarning, fmt.Sprintf("%s: %s", c.dirname, englishList(suspiciousEntries))
 	}
-
-	return checkOK, fmt.Sprintf("no suspicious entries found in %s", c.dirname)
+	return checkOK, fmt.Sprintf("%s: no suspicious entries", c.dirname)
 }
 
 func (c *versionCheck) Name() string {
