@@ -48,12 +48,14 @@ func TestScript(t *testing.T) {
 			"chhome":         cmdChHome,
 			"cmpmod":         cmdCmpMod,
 			"edit":           cmdEdit,
+			"issymlink":      cmdIsSymlink,
 			"mkfile":         cmdMkFile,
 			"mkageconfig":    cmdMkAGEConfig,
 			"mkgitconfig":    cmdMkGitConfig,
 			"mkgpgconfig":    cmdMkGPGConfig,
 			"mkhomedir":      cmdMkHomeDir,
 			"mksourcedir":    cmdMkSourceDir,
+			"readlink":       cmdReadLink,
 			"removeline":     cmdRemoveLine,
 			"rmfinalnewline": cmdRmFinalNewline,
 			"unix2dos":       cmdUNIX2DOS,
@@ -161,6 +163,23 @@ func cmdEdit(ts *testscript.TestScript, neg bool, args []string) {
 	}
 }
 
+// cmdIsSymlink returns true if all of its arguments are symlinks.
+func cmdIsSymlink(ts *testscript.TestScript, neg bool, args []string) {
+	for _, arg := range args {
+		filename := ts.MkAbs(arg)
+		info, err := os.Lstat(filename)
+		if err != nil {
+			ts.Fatalf("%s: %v", arg, err)
+		}
+		switch isSymlink := info.Mode().Type() == fs.ModeSymlink; {
+		case isSymlink && neg:
+			ts.Fatalf("%s is a symlink", arg)
+		case !isSymlink && !neg:
+			ts.Fatalf("%s is not a symlink", arg)
+		}
+	}
+}
+
 // cmdMkFile creates empty files.
 func cmdMkFile(ts *testscript.TestScript, neg bool, args []string) {
 	if neg {
@@ -377,6 +396,22 @@ func cmdMkSourceDir(ts *testscript.TestScript, neg bool, args []string) {
 	}
 }
 
+// cmdReadLink reads a symlink and verifies that its target is as expected.
+func cmdReadLink(ts *testscript.TestScript, neg bool, args []string) {
+	if len(args) != 2 {
+		ts.Fatalf("usage: readlink path target")
+	}
+	filename := ts.MkAbs(args[0])
+	link, err := os.Readlink(filename)
+	ts.Check(err)
+	switch {
+	case !neg && link != args[1]:
+		ts.Fatalf("readlink: %s -> %s, expected %s", args[0], link, args[1])
+	case neg && link == args[1]:
+		ts.Fatalf("readlink: %s -> %s, expected ! %s", args[0], link, args[1])
+	}
+}
+
 // cmdRemoveLine removes lines matching line from file, which must be present.
 func cmdRemoveLine(ts *testscript.TestScript, neg bool, args []string) {
 	if neg {
