@@ -9,6 +9,7 @@ import (
 	"path/filepath"
 	"runtime"
 
+	"github.com/bradenhilton/mozillainstallhash"
 	"howett.net/plist"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
@@ -79,6 +80,15 @@ func (c *Config) lookPathTemplateFunc(file string) string {
 	}
 }
 
+func (c *Config) mozillaInstallHashTemplateFunc(path string) string {
+	mozillaInstallHash, err := mozillainstallhash.MozillaInstallHash(path)
+	if err != nil {
+		returnTemplateError(err)
+		return ""
+	}
+	return mozillaInstallHash
+}
+
 func (c *Config) outputTemplateFunc(name string, args ...string) string {
 	output, err := c.baseSystem.IdempotentCmdOutput(exec.Command(name, args...))
 	if err != nil {
