@@ -42,7 +42,7 @@ func (c *Config) runVerifyCmd(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	if dryRunSystem.Modified() {
-		return ErrExitCode(1)
+		return ExitCodeError(1)
 	}
 	return nil
 }
